@@ -252,6 +252,12 @@ func (c *panicMatchesChecker) Check(got interface{}, args []interface{}, note fu
 //
 //     c.Assert(got, qt.IsNil)
 //
+// As a special case, if the value is nil but implements the
+// error interface, it is still considered to be non-nil.
+// This means that IsNil will fail on an error value that happens
+// to have an underlying nil value, because that's
+// invariably a mistake.
+// See https://golang.org/doc/faq#nil_error.
 var IsNil Checker = &isNilChecker{
 	argNames: []string{"got"},
 }
@@ -266,10 +272,18 @@ func (c *isNilChecker) Check(got interface{}, args []interface{}, note func(key
 		return nil
 	}
 	value := reflect.ValueOf(got)
+	_, isError := got.(error)
 	if canBeNil(value.Kind()) && value.IsNil() {
+		if isError {
+			// It's an error with an underlying nil value.
+			return fmt.Errorf("error containing nil value of type %T. See https://golang.org/doc/faq#nil_error", got)
+		}
 		return nil
 	}
-	return fmt.Errorf("%#v is not nil", got)
+	if isError {
+		return errors.New("got non-nil error")
+	}
+	return errors.New("got non-nil value")
 }
 
 // HasLen is a Checker checking that the provided value has the given length.
@@ -360,6 +374,52 @@ func (c *satisfiesChecker) Check(got interface{}, args []interface{}, note func(
 	return fmt.Errorf("value does not satisfy predicate function")
 }
 
+// IsTrue is a Checker checking that the provided value is true.
+// The value must have a boolean underlying type.
+//
+// For instance:
+//
+//     c.Assert(true, qt.IsTrue)
+//     c.Assert(myBoolean(false), qt.IsTrue)
+//
+var IsTrue Checker = &boolChecker{
+	want: true,
+}
+
+// IsFalse is a Checker checking that the provided value is false.
+// The value must have a boolean underlying type.
+//
+// For instance:
+//
+//     c.Assert(false, qt.IsFalse)
+//     c.Assert(IsValid(), qt.IsFalse)
+//
+var IsFalse Checker = &boolChecker{
+	want: false,
+}
+
+type boolChecker struct {
+	want bool
+}
+
+// Check implements Checker.Check by checking that got == c.want.
+func (c *boolChecker) Check(got interface{}, args []interface{}, note func(key string, value interface{})) (err error) {
+	v := reflect.ValueOf(got)
+	if v.IsValid() && v.Kind() == reflect.Bool {
+		if v.Bool() != c.want {
+			return fmt.Errorf("value is not %v", c.want)
+		}
+		return nil
+	}
+	note("value", got)
+	return BadCheckf("value does not have a bool underlying type")
+}
+
+// ArgNames implements Checker.ArgNames.
+func (c *boolChecker) ArgNames() []string {
+	return []string{"got"}
+}
+
 // Not returns a Checker negating the given Checker.
 //
 // For instance:
@@ -405,7 +465,7 @@ func (c *notChecker) Check(got interface{}, args []interface{}, note func(key st
 //     c.Assert([]int{3,5,7,99}, qt.Contains, 7)
 //
 var Contains Checker = &containsChecker{
-	argNames: []string{"got", "want"},
+	argNames: []string{"container", "want"},
 }
 
 type containsChecker struct {
